function param = prtr(modelname, paraname)
%  sets parameter transformation type and arguments
% /********************************************************************
% **   Each row has the following specification:
% **
% **    tr~a~b~c
% **
% **    tr parameter transformation type
% **        0: no transformation needed
% **        1: [a,b] -> [-1,1] -> [-inf,inf] by (1/c)*c*z/sqrt(1-c*z^2)
% **        2: [0,inf] -> [-inf,inf] by b + (1/c)*ln(para[i]-a);
% **    a  transformation argument a (usually lower bound)
% **    b  transformation argument b (usually upper bound)
% **    c  transformation argument c
% ********************************************************************/

if strcmp(modelname, 'HB2012_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
   
elseif strcmp(modelname, 'HB2012_sbsv_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigr0       = [ 2, 1e-7, 100, 1];
    sigg0       = [ 2, 1e-7, 100, 1];
    sigz0       = [ 2, 1e-7, 100, 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];


elseif strcmp(modelname, 'HB2012ST_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
   
elseif strcmp(modelname, 'HB2012ST_sbsv_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigr0       = [ 2, 1e-7, 100, 1];
    sigg0       = [ 2, 1e-7, 100, 1];
    sigz0       = [ 2, 1e-7, 100, 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    
elseif strcmp(modelname, 'HB2012_trgt_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigtg = [ 2, 1e-7, 100, 1];
    tg0   = [0, -100, 100, 1];
    sigmtg = [1 , 1e-8  , 5       , 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    
    
elseif strcmp(modelname, 'HB2012_trgt_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigtg = [ 2, 1e-7, 100, 1];
    tg0   = [0, -100, 100, 1];
    sigmtg = [1 , 1e-8  , 5       , 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    
%     zz0 = [0, -100, 100, 1];
    
elseif strcmp(modelname, 'HB2012_trgtar_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigtg = [ 2, 1e-7, 100, 1];
    tg0   = [0, -100, 100, 1];
    sigmtg = [1 , 1e-8  , 5       , 1];
    rhoTG = [ 1, 1e-7, 1, 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];

elseif strcmp(modelname, 'HB2012_trgt_sbsv_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigr0       = [ 2, 1e-7, 100, 1];
    sigg0       = [ 2, 1e-7, 100, 1];
    sigz0       = [ 2, 1e-7, 100, 1];
    
    sigtg = [ 2, 1e-7, 100, 1];
    tg0   = [0, -100, 100, 1];
    sigmtg = [1 , 1e-8  , 5       , 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    
%     zz0 = [0, -100, 100, 1];
    
elseif strcmp(modelname, 'HB2012_trgtar_sbsv_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigr0       = [ 2, 1e-7, 100, 1];
    sigg0       = [ 2, 1e-7, 100, 1];
    sigz0       = [ 2, 1e-7, 100, 1];
    
    sigtg = [ 2, 1e-7, 100, 1];
    tg0   = [0, -100, 100, 1];
    sigmtg = [1 , 1e-8  , 5       , 1];
    rhoTG = [ 1, 1e-7, 1, 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    
elseif strcmp(modelname, 'HB2012ST_trgt_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigtg = [ 2, 1e-7, 100, 1];
    tg0   = [0, -100, 100, 1];
    sigmtg = [1 , 1e-8  , 5       , 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    
%     zz0 = [0, -100, 100, 1];
    
elseif strcmp(modelname, 'HB2012ST_trgtar_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigtg = [ 2, 1e-7, 100, 1];
    tg0   = [0, -100, 100, 1];
    sigmtg = [1 , 1e-8  , 5       , 1];
    rhoTG = [ 1, 1e-7, 1, 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];

elseif strcmp(modelname, 'HB2012ST_trgt_sbsv_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigr0       = [ 2, 1e-7, 100, 1];
    sigg0       = [ 2, 1e-7, 100, 1];
    sigz0       = [ 2, 1e-7, 100, 1];
    
    sigtg = [ 2, 1e-7, 100, 1];
    tg0   = [0, -100, 100, 1];
    sigmtg = [1 , 1e-8  , 5       , 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    
%     zz0 = [0, -100, 100, 1];
    
elseif strcmp(modelname, 'HB2012ST_trgtar_sbsv_')
    sig_C       = [ 2, 1e-5, 10, 1];
    nu_l        = [ 2, 1e-5, 10, 1];
    iota_p      = [ 1, 1e-7, 0.99999, 1];
    zeta_p      = [ 1, 1e-7, 0.99999, 1];
    psi1        = [ 2, 0.95, 10, 1];
    psi2        = [ 2, 1e-5, 10, 1];
    rhor       = [ 1, 1e-7, 0.99999, 1];
    rrst   = [ 2, 1e-7, 20, 1];
    pist   = [ 2, 1e-7, 20, 1];
    gamst  = [ 0, -20, 20, 1];
    rhog       = [ 1, 1e-7, 0.9999, 1];
    rhoz       = [ 1, 1e-7, 1, 1];
    varphi_z    = [ 1, -0.99999, 0.9999, 1];
    sigr       = [ 2, 1e-7, 100, 1];
    sigg       = [ 2, 1e-7, 100, 1];
    sigz       = [ 2, 1e-7, 100, 1];
    
    sigr0       = [ 2, 1e-7, 100, 1];
    sigg0       = [ 2, 1e-7, 100, 1];
    sigz0       = [ 2, 1e-7, 100, 1];
    
    sigtg = [ 2, 1e-7, 100, 1];
    tg0   = [0, -100, 100, 1];
    sigmtg = [1 , 1e-8  , 5       , 1];
    rhoTG = [ 1, 1e-7, 1, 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    
% elseif strcmp(modelname, 'HB2012_sbsv_trgt_')
%     sig_C       = [ 2, 1e-5, 10, 1];
%     nu_l        = [ 2, 1e-5, 10, 1];
%     iota_p      = [ 1, 1e-7, 0.99999, 1];
%     zeta_p      = [ 1, 1e-7, 0.99999, 1];
%     psi1        = [ 2, 0.95, 10, 1];
%     psi2        = [ 2, 1e-5, 10, 1];
%     rhor       = [ 1, 1e-7, 0.99999, 1];
%     rrst   = [ 2, 1e-7, 20, 1];
%     pist   = [ 2, 1e-7, 20, 1];
%     gamst  = [ 0, -20, 20, 1];
%     rhog       = [ 1, 1e-7, 0.9999, 1];
%     rhoz       = [ 1, 1e-7, 1, 1];
%     varphi_z    = [ 1, -0.99999, 0.9999, 1];
%     sigr       = [ 2, 1e-7, 100, 1];
%     sigg       = [ 2, 1e-7, 100, 1];
%     sigz       = [ 2, 1e-7, 100, 1];
%     
%     sigr0       = [ 2, 1e-7, 100, 1];
%     sigg0       = [ 2, 1e-7, 100, 1];
%     sigz0       = [ 2, 1e-7, 100, 1];
%     
%     sigtg = [ 2, 1e-7, 100, 1];
% %     sigtg0 = [ 2, 1e-7, 100, 1];
%     tg0   = [0, -100, 100, 1];
%     sigmtg = [1 , 1e-8  , 5       , 1];
%     
%     % for measurement shocks
%     sigmy = [1 , 1e-8  , 5       , 1];
%     sigmp = [1 , 1e-8  , 5       , 1];
%     sigmr = [1 , 1e-8  , 5       , 1];
%     
elseif strcmp(modelname, 'NK2HAGR_')
    
    % transformation
    h     = [1, 1e-5, 1, 1];
    nu_l  = [1, 1e-5, 100, 1];
    lam   = [1, 1e-5, 1, 1];
    zet  = [1, 1e-5, 1, 1];
    iota  = [1, 1e-5, 1, 1];
    
    psi1  = [1 , 0.1   , 10      , 1];
    psi2  = [1 , 1e-8  , 10      , 1];
    rhor  = [1 , 1e-8  , 0.99999 , 1];
    rhog  = [1 , 1e-8  , 0.99999 , 1];
    rhoz  = [1 , 1e-8  , 0.99999 , 1];
    rrst  = [1 , 1e-8  , 10      , 1];
    pist  = [1 , 1e-8  , 20      , 1];
    pistst  = [1 , 1e-8  , 20      , 1];
    gamst = [1 , -5    , 5       , 1];
    sigr  = [1 , 1e-8  , 5       , 1];
    sigg  = [1 , 1e-8  , 5       , 1];
    sigz  = [1 , 1e-8  , 5       , 1];
    
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    
    sigtg = [1 , 1e-8  , 5       , 1];
    tg0   = [1 , -10  , 10       , 1];
    
    
elseif strcmp(modelname, 'NKASGAPlogkapGENSYS_')||strcmp(modelname, 'NKASGRlogkapGENSYS_')...
        ||strcmp(modelname, 'oldpaper2012_')
    % transformation
    tau   = [1 , 1e-5  , 10      , 1];
    nu    = [1 , 1e-5  , 0.99999 , 1];
    kap   = [1 , 1e-5  , 1       , 1];
    cyst  = [1 , 1e-5  , 0.99999 , 1];
    psi1  = [1 , 0.1   , 10      , 1];
    psi2  = [1 , 1e-5  , 10      , 1];
    rhor  = [1 , 1e-5  , 0.99999 , 1];
    rhog  = [1 , 1e-5  , 0.99999 , 1];
    rhoz  = [1 , 1e-5  , 0.99999 , 1];
    rrst  = [1 , 1e-5  , 10      , 1];
    pist  = [1 , 1e-5  , 20      , 1];
    gamst = [1 , -5    , 5       , 1];
    sigr  = [1 , 1e-8  , 5       , 1];
    sigg  = [1 , 1e-8  , 5       , 1];
    sigz  = [1 , 1e-8  , 5       , 1];
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
elseif strcmp(modelname, 'NKASGAPITlogkapGENSYS_')||strcmp(modelname, 'NKASGRITlogkapGENSYS_')
    % transformation
    tau   = [1 , 1e-5  , 10      , 1];
    nu    = [1 , 1e-5  , 0.99999 , 1];
    kap   = [1 , 1e-5  , 1       , 1];
    cyst  = [1 , 1e-5  , 0.99999 , 1];
    psi1  = [1 , 0.1   , 10      , 1];
    psi2  = [1 , 1e-5  , 10      , 1];
    rhor  = [1 , 1e-5  , 0.99999 , 1];
    rhog  = [1 , 1e-5  , 0.99999 , 1];
    rhoz  = [1 , 1e-5  , 0.99999 , 1];
    rrst  = [1 , 1e-5  , 10      , 1];
    pist  = [1 , 1e-5  , 20      , 1];
    gamst = [1 , -5    , 5       , 1];
    sigr  = [1 , 1e-8  , 5       , 1];
    sigg  = [1 , 1e-8  , 5       , 1];
    sigz  = [1 , 1e-8  , 5       , 1];
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    sigtg = [1 , 1e-8  , 5       , 1];
    tg0   = [1 , -10  , 10       , 1];
elseif strcmp(modelname, 'NKASGAPIT2logkapGENSYS_')||strcmp(modelname, 'NKASGRIT2logkapGENSYS_')
    % transformation
    tau   = [1 , 1e-5  , 10      , 1];
    nu    = [1 , 1e-5  , 0.99999 , 1];
    kap   = [1 , 1e-5  , 1       , 1];
    cyst  = [1 , 1e-5  , 0.99999 , 1];
    psi1  = [1 , 0.1   , 10      , 1];
    psi2  = [1 , 1e-5  , 10      , 1];
    rhor  = [1 , 1e-5  , 0.99999 , 1];
    rhog  = [1 , 1e-5  , 0.99999 , 1];
    rhoz  = [1 , 1e-5  , 0.99999 , 1];
    rrst  = [1 , 1e-5  , 10      , 1];
    pist  = [1 , 1e-5  , 20      , 1];
    gamst = [1 , -5    , 5       , 1];
    sigr  = [1 , 1e-8  , 5       , 1];
    sigg  = [1 , 1e-8  , 5       , 1];
    sigz  = [1 , 1e-8  , 5       , 1];
    % for measurement shocks
    sigmy = [1 , 1e-8  , 5       , 1];
    sigmp = [1 , 1e-8  , 5       , 1];
    sigmr = [1 , 1e-8  , 5       , 1];
    sigtg = [1 , 1e-8  , 5       , 1];
    tg0   = [1 , -10  , 10       , 1];
    sigme = [1 , 1e-8  , 5       , 1];
else
    disp('prtr: no modelname');
end

% assign values
npara = size(paraname,1);
param = nan*ones(npara,4);
for i=1:1:npara;
    eval(['param(', num2str(i),',:) = ', paraname{i}, ';']);
end




