function biglps = RBLPS(tempsol, tempsv, YYP, npath, estinfo)
% Rao-Blackwellized LPS
% global is_sbsv
% i=1;
% tempsol = mh_sol{i};
% tempsv.Ch = sv_C(i,:)';
% tempsv.Rh = sv_R(i,:)';
% tempsv.Vh = sv_V(i,:)';

% input: tempsol, tempsv, YYP, npath, estinfo
% output: lps

s0t = tempsol.Xlastfix; %mean
P0t = tempsol.XlastPT; %variance

data = YYP;
hact = size(data,1);
nv   = size(data,2);
lps  = zeros(hact,nv+1); %lps = [v1,v2,v3,all];

% recover coeff
DD = tempsol.DD;
ZZ = tempsol.ZZ;
HH = tempsol.HH;

CC = tempsol.CC;
TT = tempsol.TT;
RR = tempsol.RR;


if estinfo.sbsv==1
% if is_sbsv == 1
    RR = tempsol.RR*sqrt(tempsol.QQ1);
end


% loop over traj
biglps = nan*ones(npath,(nv+1)*hact); % [v1,v2,v3,all]

for itraj = 1:1:npath


    if estinfo.SVdo == 1
        h_aT = tempsol.h_aT;
        h_PT = tempsol.h_PT;
        ne   = size(h_aT,1);
        h0t  = h_aT + diag(sqrt(h_PT))*randn(ne,1);
        
        Rh   = tempsv.Rh;
        Vh   = tempsv.Vh;
        Ch   = tempsv.Ch;
    end

for t = 1:1:hact;
    % transition for h(t)
    if estinfo.SVdo == 1
        h0t = Ch + diag(Rh)*h0t + diag(sqrt(Vh))*randn(ne,1);
    else
        h0t = 0;
    end
    
    % TV variance (sigt is TV standard dev, nobs by ne)
    S2 = diag(exp(2*h0t));
    
    % forecasting
    s1t = CC + TT*s0t;
    P1t = TT*P0t*TT' + RR*S2*RR';
    P1t = symmat(P1t);

    % forecast error    
    for jj=1:1:nv+1 % individual updating
        
        if jj >nv    
            temp_y1 = data(t,:)';
            temp_DD = DD;
            temp_ZZ = ZZ;
            temp_HH = HH;
        else
            temp_y1 = data(t,jj)';
            temp_DD = DD(jj,:);
            temp_ZZ = ZZ(jj,:);
            temp_HH = HH(jj,jj);
        end
        temp_ny    = size(temp_y1,1);
        temp_e1    = temp_y1-temp_DD-temp_ZZ*s1t;			     % forecase error
        temp_f1inv = inv(temp_ZZ*P1t*temp_ZZ'+temp_HH*temp_HH');     % inverse of variance of forecast error
        %temp_K     = P1t*temp_ZZ'*temp_f1inv;     	 % Kalman gain matrix
        
        % log likelihood
        lps(t,jj) = -0.5*temp_ny*log(2*pi) + 0.5*log(det(temp_f1inv)) - 0.5*temp_e1'*temp_f1inv*temp_e1;
    end
    
    
    % updating (We are computing lps, so no data to update)
    %s0t = s1t + K*e1;
    %P0t = P1t - K*sysm.ZZ*P1t;

    s0t = s1t;
    P0t = P1t;
end
    biglps(itraj,:) = reshape(lps,1,[]);
end
    
    