function [hssn, varargout] = nhess(fcn, para, varargin)
% An and Schorfheide's code (modified by Minchul)
% hssn     : hessian calculated by subset of fullhssn (simple average of them)
% errorij  : error control for correlation from this hssn to be withn 1
% fullhssn : hessians based on various step size 

% printing format
fmt = '%5.0f';

npara = length(para);

% Compute Hessian, element by element, fine tune with dxscale
% two values for step sizes to approximate hessian
fix1 = 3;
fix2 = 4;

ndx = 6;
h0  = exp(-(6:2:(6+2*(ndx-1)))); %step size

hssn     = zeros(npara, npara);
hessdiag = zeros(ndx,1);

dxscale  = ones(npara,1); % specify different scales across parameters

% % *** mc modification
% h0 = [0.01, 0.1, 0.5, 1, 10, 100];
% dxscale  = 1e-5*(max(abs(para),1e-8*ones(npara,1)));

dxscale  = sparse(1:npara,1:npara,dxscale,npara,npara);


fx = feval(fcn, para, varargin{:}); %evaluate function

disp('  ');
disp('  ');
disp('Copmuting Hessian ...');
disp(['Step sizes  : ', num2str(h0, '%10.7f, ')]);
disp(['<< Only ', num2str(fix1), ' th and ', num2str(fix2), ' th values are used >>']);
disp(['------------------------------------------']);
disp(sprintf(['  diagonal elements     :   ' fmt ],npara));

% matrix for saving all the deviations
allelements = zeros(npara+npara*(npara-1)/2, ndx);
a_indx = 1;

% Compute diagonal elements first
for seli = 1:npara
    
    h = dxscale(:,seli)*h0;
    
        for i=1:ndx
            
            % forward point
            paradx = para + h(:,i);
            
            % backward point
            parady = para - h(:,i);
            
            % evaluate function at forward and backward points
            fdx = feval(fcn, paradx, varargin{:});
            fdy = feval(fcn, parady, varargin{:});
            
            % Hessian
            hessdiag(i) = -(2*fx-fdx-fdy)/(h(seli,i))^2;
        end
        
        allelements(a_indx,:) = hessdiag';
        a_indx = a_indx+1;
        
        hssn(seli,seli) = 0.5*(hessdiag(fix1)+hessdiag(fix2));
        disp(sprintf(['                            ' fmt ],seli));
end

% Now compute off-diagonal elements
% Make sure that correlations are between -1 and 1
% errorij contains the index of elements that are invalid
disp('  ');
disp(sprintf(['  off-diagonal elements :   ' fmt ],npara*(npara-1)/2));

errorij = [];
k = 1;

for seli = 1:npara
    
    hi = dxscale(:,seli)*h0;
    
    for selj = (seli+1):npara
        
        hj = dxscale(:,selj)*h0;
        
        for i=1:ndx
            
            % forward to seli-th direction
            paradx = para + hi(:,i);
            
            % backward to selj-th direction
            parady = para - hj(:,i);
            
            % forward to seli-th direction and backward to selj-th direction
            paradxdy = paradx - hj(:,i);
            
            % evaluate functions
            fdx = feval(fcn, paradx, varargin{:});
            fdy = feval(fcn, parady, varargin{:});
            fdxdy = feval(fcn, paradxdy, varargin{:});
            
            hessdiag(i) = -(fx-fdx-fdy+fdxdy)/(hi(seli,i)*hj(selj,i));
        end
        
        hssn(seli,selj) = 0.5*(hessdiag(fix1) + hessdiag(fix2));
        
        % calculate correlation
        if (hssn(seli, seli)==0)||(hssn(selj,selj)==0) % when the variance are zeros
            corrij = 0;
        else
            corrij = hssn(seli,selj)/sqrt(hssn(seli,seli)*hssn(selj,selj));
        end
        
        % outlier-lik correlations
        nocorrection = 0;
        if ~nocorrection
            if (abs(corrij)>0.98) % abs(cor) is too big -> error
                disp(['correlation too large ... corrected!: ', ...
                    num2str(seli), ', ', num2str(selj), ', corr= ', num2str(corrij)]);
                hssn(seli, selj) = sign(corrij)*0.9*sqrt(hssn(seli,seli)*hssn(selj,selj));
                
                hssn(seli,selj)/sqrt(hssn(seli,seli)*hssn(selj,selj))
                
                errorij = [errorij; seli selj corrij];
                
            elseif (abs(corrij)<0.005) % abs(corr) is too small, make it 0
                disp(['correlation too small ... corrected!: ', ...
                    num2str(seli), ', ', num2str(selj), ', corr= ', num2str(corrij)]);
                hssn(seli, selj) = 0;
                errorij = [errorij; seli selj corrij];
            end
        end
        
        hssn(selj, seli) = hssn(seli, selj); %symmetrize
        
        allelements(a_indx,:) = hessdiag';
        a_indx = a_indx + 1;
        
        if mod(k,5)==0;
            disp(sprintf(['                            ' fmt ],k));
        end
        k=k+1;
        
    end
end
    
if ~isreal(hssn)
    disp('-----------------------');
    disp('some hssn was not real');
    hssn = real(hssn);
end

if min(eig(-hssn))<0
    disp('-----------------------');
    disp('negative hssn contains negative eigvals');
end

varargout = {errorij, allelements};

    
    
    
    
    
    
    
    
    

