% Model Specification and Global Setting
% This script sets some of settings for DSGE estimation
% [*] Example of the specification
% Among others, the followings are important ones:
% 
% modelname = {'HB2012ST_trgtar_', 'HB2012ST_trgtar_sbsv_'}
% where 
% 'HB2012ST_trgtar': Benchmark model (Const, SV-AR, SV-UR)
% 'HB2012ST_trgtar_sbsv': we model variance to break once with a known break date (see main text, DV-SB)
% 
% mprior = {34, 64}
% 34: tight prior on the constant target rate in the policy rule (Benchmark)
% 64: random walk assumption for the time-varying target rate process (for SV-UR)
% 
% estinfo.SVdo = {0, 1} : 1 if we have stochastic volatility in the model. Otherwise, we assume constant volatility model.
% estinfo.SVloc = {0 or [1,2,3]}
% If 0, it becomes the constant volatility model.
% If [1,2,3], it 
% 
% estinfo.sbsv = {0,1} : 1 if we want constant volatility model to have a structural break  	 
%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%
% Following two variables are main option variable. One can leave others as it is.

% Specification
estinfo.mspec = 4; %1=const, 2=SV-RW, 3=SV-AR, 4=DV-SB

% Real-time data
estinfo.sampleind = 70; % index of the real-time data for estimation/prediction (from 1 to 78)

%%%%%%%%%%%%%%%%%%%%%%

%% Set-up the global variables

if estinfo.mspec == 1 %const model
    % Model name
    modelname = 'HB2012ST_trgtar_'; % %HB2012ST_trgtar_ or HB2012ST_trgtar_sbsv_
    estinfo.trgt_measurement = 1;
    % Inflation expectation measurement
    if estinfo.trgt_measurement == 1
        lmeasurement = 'm1';
    elseif estinfo.trgt_measurement == 0
        lmeasurement = '';
    end
    
    % SV and estimation
    estinfo.SVdo     = 0; %1 if structural shock has SV
    estinfo.SVloc    = []; % location where we want to put SV
    estinfo.Qone     = 1; %where to put long-run h
    
    estinfo.sbsv     = 0; %structural break with known date
    if estinfo.sbsv == 1 %if estinfo.sbsv, then we don't put SV
        estinfo.SVdo     = 0; %1 if structural shock has SV
        estinfo.SVloc    = []; % location where we want to put SV
    end
    
    estinfo.eachbin  = [7,8,8]; %number of parameters in each block [6,6,7] for const,
    
    % prior
    mprior    = 34;
    
elseif estinfo.mspec == 2 %SV-RW
        % Model name
    modelname = 'HB2012ST_trgtar_'; % %HB2012ST_trgtar_ or HB2012ST_trgtar_sbsv_
    estinfo.trgt_measurement = 1;
    % Inflation expectation measurement
    if estinfo.trgt_measurement == 1
        lmeasurement = 'm1';
    elseif estinfo.trgt_measurement == 0
        lmeasurement = '';
    end
    
    % SV and estimation
    estinfo.SVdo     = 1; %1 if structural shock has SV
    estinfo.SVloc    = [1,2,3]; % location where we want to put SV
    estinfo.Qone     = 0; %where to put long-run h
    
    estinfo.sbsv     = 0; %structural break with known date
    if estinfo.sbsv == 1 %if estinfo.sbsv, then we don't put SV
        estinfo.SVdo     = 0; %1 if structural shock has SV
        estinfo.SVloc    = []; % location where we want to put SV
    end
    
    estinfo.eachbin  = [7,8,8]; %number of parameters in each block [6,6,7] for const,
    
    % prior
    mprior    = 64;
    
    
elseif estinfo.mspec == 3 %SV-AR
    % Model name
    modelname = 'HB2012ST_trgtar_'; % %HB2012ST_trgtar_ or HB2012ST_trgtar_sbsv_
    estinfo.trgt_measurement = 1;
    % Inflation expectation measurement
    if estinfo.trgt_measurement == 1
        lmeasurement = 'm1';
    elseif estinfo.trgt_measurement == 0
        lmeasurement = '';
    end
    
    % SV and estimation
    estinfo.SVdo     = 1; %1 if structural shock has SV
    estinfo.SVloc    = [1,2,3]; % location where we want to put SV
    estinfo.Qone     = 1; %where to put long-run h
    
    estinfo.sbsv     = 0; %structural break with known date
    if estinfo.sbsv == 1 %if estinfo.sbsv, then we don't put SV
        estinfo.SVdo     = 0; %1 if structural shock has SV
        estinfo.SVloc    = []; % location where we want to put SV
    end
    
    estinfo.eachbin  = [7,8,8]; %number of parameters in each block [6,6,7] for const,
    
    % prior
    mprior    = 34;
    
elseif estinfo.mspec == 4 %DV-SB
    % Model name
    modelname = 'HB2012ST_trgtar_sbsv_'; % %HB2012ST_trgtar_ or HB2012ST_trgtar_sbsv_
    estinfo.trgt_measurement = 1;
    
    % Inflation expectation measurement
    if estinfo.trgt_measurement == 1
        lmeasurement = 'm1';
    elseif estinfo.trgt_measurement == 0
        lmeasurement = '';
    end
    
    % SV and estimation
    estinfo.SVdo     = 0; %1 if structural shock has SV
    estinfo.SVloc    = [1,2,3]; % location where we want to put SV
    estinfo.Qone     = 1; %where to put long-run h
    
    estinfo.sbsv     = 1; %structural break with known date
    if estinfo.sbsv == 1 %if estinfo.sbsv, then we don't put SV
        estinfo.SVdo     = 0; %1 if structural shock has SV
        estinfo.SVloc    = []; % location where we want to put SV
    end
    
    % estinfo.eachbin  = [6,6,7]; %number of parameters in each block [6,6,7] for const,
    estinfo.eachbin  = [9,9,8]; %number of parameters in each block [6,6,7] for const,
    
    % prior
    mprior    = 34;
end

%% Other specification (common part)

estinfo.cc       = 1.5; % scale for MH draws
estinfo.SVsave   = 1; %save SV

% number for MH sequence
estinfo.mhrun = '3';

% per-capita in the estimation/prediction
estinfo.percapita = 0;
if estinfo.percapita == 1
    lpercapita = '';
elseif estinfo.percapita == 0
    lpercapita = 'pc0';
end
% dataset selection (we shut down this option and doesn't mean anything)
datasel   = 1; % For this paper we fix it to 1
% Order of approximation
order_app  = 1;
% number of particles
n_particle = 0;

% use inflation expectation??
if strcmp(modelname, 'NKASGAPIT2logkapGENSYS_')||strcmp(modelname, 'NKASGRIT2logkapGENSYS_') ...
        || strcmp(modelname, 'HB2012_trgt_')|| strcmp(modelname, 'HB2012_trgtar_')  || strcmp(modelname, 'HB2012_sbsv_trgt_') ...
        || strcmp(modelname, 'HB2012ST_trgt_')|| strcmp(modelname, 'HB2012ST_trgtar_') ...
        || strcmp(modelname, 'HB2012ST_trgt_sbsv_')|| strcmp(modelname, 'HB2012ST_trgtar_sbsv_')
    estinfo.infle = 1; %use inflation expectation data
    nv_  = 4;
else
    estinfo.infle = 0;
    nv_  = 3;
end

estinfo.trgt_measurement = 1;
if estinfo.trgt_measurement == 1
    lmeasurement = 'm1';
elseif estinfo.trgt_measurement == 0
    lmeasurement = '';
end


%% estinfo setting
estinfo.modelname = modelname;

% likelihood evaluation
estinfo.mex   = 1; % use mex-file for particle filter or kim's filter
estinfo.ordqz = 1; %gensys
estinfo.zerocleaning = 1e-15; %gensys output
estinfo.kf = 'an'; % 'an' or 'mc', flag in evalmod_kalman

% mh
estinfo.adapt    = 0; % 1 if we do adaptation
estinfo.nadapt   = 5000; % # of adaptation

% estinfo.pfparfor = 1; % 1 for pararell for particle filter
% estinfo.ncore    = 1; % # of cores in parfor when parfor is used
% estinfo.nparticle = 300; % for particle filter

estinfo.predXlast = 1; %if we want to generate prediction

% Forecasting configuration
hmax_ = 8;

% Simulation setting
% nsimul_   = 30000;
nsimul_   = 6000;
ncounter_ = 1000;
% nburn_    = 10000;
nburn_    = 1000;
nuse_     = 10;
npaths_   = 10;

% nsimul_   = 300;
% ncounter_ = 100;
% nburn_    = 100;
% nuse_     = 10;
% npaths_   = 10;

% Tbegin
Tbegin = 1;

% Some other information
% subT = 0;
T0_  = 1; %we omit 4 obs to calculate liklihood


% -------------------------------------------------------------------------
% DATASEL: Simulated data
% -------------------------------------------------------------------------
ldata = ['d', num2str(datasel)];

% -------------------------------------------------------------------------
%  prior
% -------------------------------------------------------------------------
lprior = ['p', num2str(mprior)];

% -------------------------------------------------------------------------
%  perturbation order
% -------------------------------------------------------------------------
lorder = ['o', num2str(order_app)];

% % -------------------------------------------------------------------------
% %  SV
% % -------------------------------------------------------------------------
% lsv = ['s', num2str(sv_)];









